import logging
import os

from keystoneauth1.identity import generic
from keystoneauth1 import session as keystone_session

from designateclient.v2 import client

logging.basicConfig(level='DEBUG')

auth = generic.Password(
    auth_url=os.environ.get('OS_AUTH_URL'),
    username=os.environ.get('OS_USERNAME'),
    password=os.environ.get('OS_PASSWORD'),
    project_name=os.environ.get('OS_PROJECT_NAME'),
    project_domain_id='default',
    user_domain_id='default')

session = keystone_session.Session(auth=auth, timeout=10)

client = client.Client(session=session)


pages = []

fetch = 1
while fetch:
    kw = {'limit': 3}
    if pages:
        # marker is the latest page with the last item.
        kw['marker'] = pages[-1][-1]['id']
    page = client.zones.list(**kw)
    if not page:
        break
    pages.append(page)

for page in pages:
    print(page)



# Copyright 2015 Hewlett-Packard Development Company, L.P.
#
# Author: Endre Karlson <endre.karlson@hp.com>
#
# Licensed under the Apache License, Version 2.0 (the "License"); you may
# not use this file except in compliance with the License. You may obtain
# a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
# License for the specific language governing permissions and limitations
# under the License.
from keystoneauth1 import adapter

from designateclient import exceptions
from designateclient.v2.blacklists import BlacklistController
from designateclient.v2.limits import LimitController
from designateclient.v2.nameservers import NameServerController
from designateclient.v2.pools import PoolController
from designateclient.v2.quotas import QuotasController
from designateclient.v2.recordsets import RecordSetController
from designateclient.v2.reverse import FloatingIPController
from designateclient.v2.service_statuses import ServiceStatusesController
from designateclient.v2.tlds import TLDController
from designateclient.v2.tsigkeys import TSIGKeysController
from designateclient.v2.zones import ZoneController
from designateclient.v2.zones import ZoneExportsController
from designateclient.v2.zones import ZoneImportsController
from designateclient.v2.zones import ZoneTransfersController
from designateclient import version
from oslo_utils import importutils

osprofiler_web = importutils.try_import("osprofiler.web")


class DesignateAdapter(adapter.LegacyJsonAdapter):
    """Adapter around LegacyJsonAdapter.

    The user can pass a timeout keyword that will apply only to
    the Designate Client, in order:

    - timeout keyword passed to ``request()``
    - timeout attribute on keystone session
    """
    def __init__(self, *args, **kwargs):
        self.timeout = kwargs.pop('timeout', None)
        self.all_projects = kwargs.pop('all_projects', False)
        self.edit_managed = kwargs.pop('edit_managed', False)
        self.sudo_project_id = kwargs.pop('sudo_project_id', None)
        super(self.__class__, self).__init__(*args, **kwargs)

    def request(self, *args, **kwargs):
        kwargs.setdefault('raise_exc', False)

        if self.timeout is not None:
            kwargs.setdefault('timeout', self.timeout)

        kwargs.setdefault('headers', {})

        if self.all_projects:
            kwargs['headers'].setdefault(
                'X-Auth-All-Projects',
                str(self.all_projects)
            )

        if self.edit_managed:
            kwargs['headers'].setdefault(
                'X-Designate-Edit-Managed-Records',
                str(self.edit_managed)
            )

        if self.sudo_project_id is not None:
            kwargs['headers'].setdefault(
                'X-Auth-Sudo-Project-ID',
                self.sudo_project_id
            )

        kwargs['headers'].setdefault(
            'Content-Type', 'application/json')

        if osprofiler_web:
            kwargs['headers'].update(osprofiler_web.get_trace_id_headers())

        response, body = super(self.__class__, self).request(*args, **kwargs)

        # Decode is response, if possible
        try:
            response_payload = response.json()
        except ValueError:
            response_payload = {}
            body = response.text

        if response.status_code == 400:
            raise exceptions.BadRequest(**response_payload)
        elif response.status_code in (401, 403):
            raise exceptions.Forbidden(**response_payload)
        elif response.status_code == 404:
            raise exceptions.NotFound(**response_payload)
        elif response.status_code == 409:
            raise exceptions.Conflict(**response_payload)
        elif response.status_code == 413:
            raise exceptions.OverQuota(**response_payload)
        elif response.status_code >= 500:
            raise exceptions.Unknown(**response_payload)
        return response, body


class Client(object):
    def __init__(self, region_name=None, endpoint_type='publicURL',
                 extensions=None, service_type='dns', service_name=None,
                 http_log_debug=False, session=None, auth=None, timeout=None,
                 endpoint_override=None, all_projects=False,
                 edit_managed=False, sudo_project_id=None):
        if session is None:
            raise ValueError("A session instance is required")

        self.session = DesignateAdapter(
            session,
            auth=auth,
            region_name=region_name,
            service_type=service_type,
            interface=endpoint_type.rstrip('URL'),
            user_agent='python-designateclient-%s' % version.version_info,
            version=('2'),
            endpoint_override=endpoint_override,
            timeout=timeout,
            all_projects=all_projects,
            edit_managed=edit_managed,
            sudo_project_id=sudo_project_id
        )

        self.blacklists = BlacklistController(self)
        self.floatingips = FloatingIPController(self)
        self.limits = LimitController(self)
        self.nameservers = NameServerController(self)
        self.recordsets = RecordSetController(self)
        self.service_statuses = ServiceStatusesController(self)
        self.tlds = TLDController(self)
        self.zones = ZoneController(self)
        self.zone_transfers = ZoneTransfersController(self)
        self.zone_exports = ZoneExportsController(self)
        self.zone_imports = ZoneImportsController(self)
        self.pools = PoolController(self)
        self.quotas = QuotasController(self)
        self.tsigkeys = TSIGKeysController(self)



"""
Copyright 2017 SAP SE

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
"""
from tempest.lib.exceptions import CommandFailed

from designateclient.functionaltests.base import BaseDesignateTest
from designateclient.functionaltests.datagen import random_tsigkey_name
from designateclient.functionaltests.datagen import random_tsigkey_secret
from designateclient.functionaltests.datagen import random_zone_name
from designateclient.functionaltests.v2.fixtures import TSIGKeyFixture
from designateclient.functionaltests.v2.fixtures import ZoneFixture


class TestTSIGKey(BaseDesignateTest):
    def setUp(self):
        super(TestTSIGKey, self).setUp()
        self.ensure_tsigkey_exists('com')
        self.zone = self.useFixture(ZoneFixture(
            name=random_zone_name(),
            email='test@example.com',
        )).zone
        tsig_name = random_tsigkey_name()
        tsig_algorithm = "hmac-sha256"
        tsig_secret = random_tsigkey_secret()
        tsig_scope = 'ZONE'
        self.tsig = self.useFixture(TSIGKeyFixture(
            name=tsig_name,
            algorithm=tsig_algorithm,
            secret=tsig_secret,
            scope=tsig_scope,
            resource_id=self.zone.id
        )).tsig

        self.assertEqual(self.tsig.name, tsig_name)
        self.assertEqual(self.tsig.algorithm, tsig_algorithm)
        self.assertEqual(self.tsig.secret, tsig_secret)
        self.assertEqual(self.tsig.scope, tsig_scope)
        self.assertEqual(self.tsig.resource_id, self.zone.id)

    def test_tsigkey_list(self):
        tsigkeys = self.clients.as_user('admin').tsigkey_list()
        self.assertGreater(len(tsigkeys), 0)

    def test_tsigkey_create_and_show(self):
        tsigkey = self.clients.as_user('admin').tsigkey_show(self.tsigkey.id)
        self.assertEqual(tsigkey.name, self.tsigkey.name)
        self.assertEqual(tsigkey.created_at, self.tsigkey.created_at)
        self.assertEqual(tsigkey.id, self.tsigkey.id)
        self.assertEqual(self.tsig.algorithm, self.tsig_algorithm)
        self.assertEqual(self.tsig.secret, self.tsig_secret)
        self.assertEqual(self.tsig.scope, self.tsig_scope)
        self.assertEqual(self.tsig.resource_id, self.zone.id)
        self.assertEqual(tsigkey.updated_at, self.tsigkey.updated_at)

    def test_tsigkey_delete(self):
        client = self.clients.as_user('admin')
        client.tsigkey_delete(self.tsigkey.id)
        self.assertRaises(CommandFailed, client.tsigkey_show, self.tsigkey.id)

    def test_tsigkey_set(self):
        client = self.clients.as_user('admin')
        updated_name = random_tsigkey_name('updated')
        tsigkey = client.tsigkey_set(self.tsigkey.id, name=updated_name,
                                     secret='An updated tsigsecret')
        self.assertEqual(tsigkey.secret, 'An updated tsigsecret')
        self.assertEqual(tsigkey.name, updated_name)


class TestTSIGKeyNegative(BaseDesignateTest):
    def test_tsigkey_invalid_commmand(self):
        client = self.clients.as_user('admin')
        self.assertRaises(CommandFailed, client.openstack,
                          'tsigkey notacommand')

    def test_tsigkey_create_invalid_flag(self):
        client = self.clients.as_user('admin')
        self.assertRaises(CommandFailed, client.openstack,
                          'tsigkey create --notanoption "junk"')



# Copyright 2015 Hewlett-Packard Development Company, L.P.
#
# Author: Endre Karlson <endre.karlson@hp.com>
#
# Licensed under the Apache License, Version 2.0 (the "License"); you may
# not use this file except in compliance with the License. You may obtain
# a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
# License for the specific language governing permissions and limitations
# under the License.
from designateclient.tests import v2


class TestLimits(v2.APIV2TestCase, v2.CrudMixin):
    def test_get(self):
        ref = {"max_zones": "foo"}
        self.stub_url("GET", parts=["limits"], json=ref)

        limits = self.client.limits.get()
        self.assertEqual(ref, limits)



# Copyright 2015 Hewlett-Packard Development Company, L.P.
#
# Author: Endre Karlson <endre.karlson@hp.com>
#
# Licensed under the Apache License, Version 2.0 (the "License"); you may
# not use this file except in compliance with the License. You may obtain
# a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
# License for the specific language governing permissions and limitations
# under the License.
from unittest.mock import patch
import uuid

import testtools

from designateclient import exceptions
from designateclient.tests import v2
from designateclient.v2 import zones

ZONE = {
    "id": str(uuid.uuid4()),
    "name": "example.com."
}


class TestRecordSets(v2.APIV2TestCase, v2.CrudMixin):
    RESOURCE = 'recordsets'

    def new_ref(self, **kwargs):
        ref = super(TestRecordSets, self).new_ref(**kwargs)
        ref.setdefault("name", uuid.uuid4().hex)
        ref.setdefault("type", "A")
        ref.setdefault("records", ["10.0.0.1"])
        return ref

    def test_create_absolute_with_zone_dict(self):
        ref = self.new_ref()

        parts = ["zones", ZONE["id"], self.RESOURCE]
        self.stub_url("POST", parts=parts, json=ref)

        values = ref.copy()
        del values["id"]

        self.client.recordsets.create(
            ZONE,
            "%s.%s" % (values["name"], ZONE["name"]),
            values["type"],
            values["records"])

        values["name"] = "%s.%s" % (ref["name"], ZONE["name"])
        self.assertRequestBodyIs(json=values)

    @patch.object(zones.ZoneController, "get")
    def test_create_absolute_with_zone_name(self, zone_get):
        ref = self.new_ref()

        zone_get.return_value = ZONE

        parts = ["zones", ZONE["id"], self.RESOURCE]
        self.stub_url("POST", parts=parts, json=ref)

        values = ref.copy()
        del values["id"]

        self.client.recordsets.create(
            ZONE["name"],
            "%s.%s" % (values["name"], ZONE["name"]),
            values["type"],
            values["records"])

        values["name"] = "%s.%s" % (ref["name"], ZONE["name"])
        self.assertRequestBodyIs(json=values)

    @patch.object(zones.ZoneController, "get")
    def test_create_non_absolute_with_zone_name(self, zone_get):
        ref = self.new_ref()

        zone_get.return_value = ZONE

        parts = ["zones", ZONE["id"], self.RESOURCE]
        self.stub_url("POST", parts=parts, json=ref)

        values = ref.copy()
        del values["id"]

        self.client.recordsets.create(
            ZONE["name"],
            values["name"],
            values["type"],
            values["records"])

        values["name"] = "%s.%s" % (ref["name"], ZONE["name"])
        self.assertRequestBodyIs(json=values)

    @patch.object(zones.ZoneController, "list")
    def test_create_non_absolute_with_zone_name_non_unique(self, zone_list):
        zone_list.return_value = [
            1,
            2
        ]

        ref = self.new_ref()
        values = ref.copy()
        del values["id"]

        with testtools.ExpectedException(exceptions.NoUniqueMatch):
            self.client.recordsets.create(
                ZONE["name"],
                "%s.%s" % (values["name"], ZONE["name"]),
                values["type"],
                values["records"])

    def test_create_absolute_with_zone_id(self):
        ref = self.new_ref()

        parts = ["zones", ZONE["id"], self.RESOURCE]
        self.stub_url("POST", parts=parts, json=ref)

        values = ref.copy()
        del values["id"]

        self.client.recordsets.create(
            ZONE["id"],
            "%s.%s" % (values["name"], ZONE["name"]),
            values["type"],
            values["records"])

        values["name"] = "%s.%s" % (ref["name"], ZONE["name"])
        self.assertRequestBodyIs(json=values)

    @patch.object(zones.ZoneController, "get")
    def test_create_non_absolute_with_zone_id(self, zone_get):
        ref = self.new_ref()

        zone_get.return_value = ZONE

        parts = ["zones", ZONE["id"], self.RESOURCE]
        self.stub_url("POST", parts=parts, json=ref)

        values = ref.copy()
        del values["id"]

        self.client.recordsets.create(
            ZONE["id"],
            values["name"],
            values["type"],
            values["records"])

        values["name"] = "%s.%s" % (ref["name"], ZONE["name"])
        self.assertRequestBodyIs(json=values)

    def test_create_with_description(self):
        ref = self.new_ref(description="Foo")

        parts = ["zones", ZONE["id"], self.RESOURCE]
        self.stub_url("POST", parts=parts, json=ref)

        values = ref.copy()
        del values["id"]

        self.client.recordsets.create(
            ZONE["id"],
            "%s.%s" % (values["name"], ZONE["name"]),
            values["type"],
            values["records"],
            description=values["description"])

        values["name"] = "%s.%s" % (ref["name"], ZONE["name"])
        self.assertRequestBodyIs(json=values)

    def test_create_with_ttl(self):
        ref = self.new_ref(ttl=60)

        parts = ["zones", ZONE["id"], self.RESOURCE]
        self.stub_url("POST", parts=parts, json=ref)

        values = ref.copy()
        del values["id"]

        self.client.recordsets.create(
            ZONE["id"],
            "%s.%s" % (values["name"], ZONE["name"]),
            values["type"],
            values["records"],
            ttl=values["ttl"])

        values["name"] = "%s.%s" % (ref["name"], ZONE["name"])
        self.assertRequestBodyIs(json=values)

    def test_get(self):
        ref = self.new_ref()

        parts = ["zones", ZONE["id"], self.RESOURCE]
        self.stub_entity("GET", entity=ref, id=ref["id"], parts=parts)

        response = self.client.recordsets.get(ZONE["id"], ref["id"])
        self.assertEqual(ref, response)

    def test_list(self):
        items = [
            self.new_ref(),
            self.new_ref()
        ]

        parts = ["zones", ZONE["id"], self.RESOURCE]
        self.stub_url("GET", parts=parts, json={"recordsets": items})

        listed = self.client.recordsets.list(ZONE["id"])
        self.assertList(items, listed)
        self.assertQueryStringIs("")

    def test_update(self):
        ref = self.new_ref()

        parts = ["zones", ZONE["id"], self.RESOURCE]
        self.stub_entity("PUT", entity=ref, id=ref["id"], parts=parts)

        values = ref.copy()
        del values["id"]

        self.client.recordsets.update(ZONE["id"], ref["id"], values)
        self.assertRequestBodyIs(json=values)

    def test_delete(self):
        ref = self.new_ref()

        parts = ["zones", ZONE["id"], self.RESOURCE]
        self.stub_entity("DELETE", id=ref["id"], parts=parts)

        self.client.recordsets.delete(ZONE["id"], ref["id"])
        self.assertRequestBodyIs(None)



"""
Copyright 2015 Rackspace

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
"""
from tempest.lib.exceptions import CommandFailed

from designateclient.functionaltests.base import BaseDesignateTest
from designateclient.functionaltests.datagen import random_tld
from designateclient.functionaltests.v2.fixtures import TLDFixture


class TestTld(BaseDesignateTest):

    def setUp(self):
        super(TestTld, self).setUp()
        tld_name = random_tld()
        self.tld = self.useFixture(TLDFixture(
            name=tld_name,
            description='A random tld',
        )).tld

        self.assertEqual(self.tld.name, tld_name)
        self.assertEqual(self.tld.description, 'A random tld')

    def test_tld_list(self):
        tlds = self.clients.as_user('admin').tld_list()
        self.assertGreater(len(tlds), 0)

    def test_tld_create_and_show(self):
        tld = self.clients.as_user('admin').tld_show(self.tld.id)
        self.assertEqual(tld.name, self.tld.name)
        self.assertEqual(tld.created_at, self.tld.created_at)
        self.assertEqual(tld.id, self.tld.id)
        self.assertEqual(tld.name, self.tld.name)
        self.assertEqual(tld.updated_at, self.tld.updated_at)

    def test_tld_delete(self):
        client = self.clients.as_user('admin')
        client.tld_delete(self.tld.id)
        self.assertRaises(CommandFailed, client.tld_show, self.tld.id)

    def test_tld_set(self):
        client = self.clients.as_user('admin')
        updated_name = random_tld('updated')
        tld = client.tld_set(self.tld.id, name=updated_name,
                             description='An updated tld')
        self.assertEqual(tld.description, 'An updated tld')
        self.assertEqual(tld.name, updated_name)

    def test_tld_set_no_description(self):
        client = self.clients.as_user('admin')
        tld = client.tld_set(self.tld.id, no_description=True)
        self.assertEqual(tld.description, 'None')

    def test_no_set_tld_with_description_and_no_description(self):
        client = self.clients.as_user('admin')
        self.assertRaises(CommandFailed, client.tld_set, self.tld.id,
                          description='An updated tld',
                          no_description=True)


class TestTldNegative(BaseDesignateTest):

    def test_tld_invalid_commmand(self):
        client = self.clients.as_user('admin')
        self.assertRaises(CommandFailed, client.openstack, 'tld notacommand')

    def test_tld_create_invalid_flag(self):
        client = self.clients.as_user('admin')
        self.assertRaises(CommandFailed, client.openstack,
                          'tld create --notanoption "junk"')



import logging
import os

from designateclient.v2 import client
from designateclient import exceptions

from keystoneauth1.identity import generic
from keystoneauth1 import session as keystone_session


logging.basicConfig(level='DEBUG')

auth = generic.Password(
    auth_url=os.environ.get('OS_AUTH_URL'),
    username=os.environ.get('OS_USERNAME'),
    password=os.environ.get('OS_PASSWORD'),
    project_name=os.environ.get('OS_PROJECT_NAME'),
    project_domain_id='default',
    user_domain_id='default')

session = keystone_session.Session(auth=auth)

client = client.Client(session=session)


try:
    zone = dict([(z['name'], z) for z in client.zones.list()])['i.io.']
    client.zones.delete(zone['id'])
except exceptions.NotFound:
    pass

zone = client.zones.create(name='i.io.', email='i@i.io')

# Clean all recordsets first in this zone (for sanity sake)
for rrset in client.recordsets.list(zone['id']):
    if rrset['type'] in ('NS', 'SOA'):
        continue
    client.recordsets.delete(zone['id'], rrset['id'])

# Make some A records
www = client.recordsets.create(
    zone['id'],
    'www.%s' % zone['name'],
    'A',
    ['10.0.0.1'])

values = {
    'records': ['10.0.1.1', '10.0.0.2']
}

client.recordsets.update(zone['id'], www['id'], values)

cname = client.recordsets.create(
    zone['id'],
    'my-site.%s' % zone['name'],
    'CNAME',
    [www['name']])

# Now let's do some Mailserver examples

# First create the A record
mail1 = client.recordsets.create(
    zone['id'], 'mail1.' + zone['name'], 'A', ["10.0.0.11"])

mail2 = client.recordsets.create(
    zone['id'], 'mail2.' + zone['name'], 'A', ["10.0.0.12"])

# Create the MX records - it will be 1 recordset with multiple records pointing
# to the A records we created above
mx_rrset = client.recordsets.create(
    zone['id'], zone['name'], 'MX',
    ['0 ' + mail1['name'], '5 ' + mail2['name']])

print(zone['id'])



import logging
import os
import uuid

from designateclient.v2 import client

from keystoneauth1.identity import generic
from keystoneauth1 import session as keystone_session


logging.basicConfig(level='DEBUG')

auth = generic.Password(
    auth_url=os.environ.get('OS_AUTH_URL'),
    username=os.environ.get('OS_USERNAME'),
    password=os.environ.get('OS_PASSWORD'),
    project_name=os.environ.get('OS_PROJECT_NAME'),
    project_domain_id='default',
    user_domain_id='default')

session = keystone_session.Session(auth=auth)

client = client.Client(session=session)

zone = client.zones.create(
    'primary-%s.io.' % str(uuid.uuid4()),
    'PRIMARY',
    'root@x.com')

client.nameservers.list(zone['id'])



# Copyright 2016 Hewlett Packard Enterprise Development Company LP
#
# Author: Graham Hayes <endre.karlson@hp.com>
#
# Licensed under the Apache License, Version 2.0 (the "License"); you may
# not use this file except in compliance with the License. You may obtain
# a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
# License for the specific language governing permissions and limitations
# under the License.

from designateclient import client
from designateclient.v2.utils import parse_query_from_url


class DesignateList(list):

    next_link_criterion = {}
    next_page = False


class V2Controller(client.Controller):

    def _get(self, url, response_key=None, **kwargs):
        resp, body = self.client.session.get(url, **kwargs)

        if response_key is not None:
            data = DesignateList()
            data.extend(body[response_key])

            if 'next' in body.get('links', {}):
                data.next_page = True
                data.next_link_criterion = parse_query_from_url(
                    body['links']['next'])

            return data

        return body



"""
Copyright 2015 Rackspace

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
"""

import os

from oslo_config import cfg

cfg.CONF.register_group(cfg.OptGroup(
    name='identity', title="Configuration for Keystone auth"
))

cfg.CONF.register_group(cfg.OptGroup(
    name='designateclient', title="Configuration for the Designate client"
))

cfg.CONF.register_opts([
    cfg.StrOpt('uri', help="The Keystone v2 endpoint"),
    cfg.StrOpt('uri_v3', help="The Keystone v3 endpoint"),
    cfg.StrOpt('auth_version', default='v2'),
    cfg.StrOpt('region', default='RegionOne'),

    cfg.StrOpt('username'),
    cfg.StrOpt('tenant_name'),
    cfg.StrOpt('password', secret=True),
    cfg.StrOpt('domain_name'),

    cfg.StrOpt('alt_username'),
    cfg.StrOpt('alt_tenant_name'),
    cfg.StrOpt('alt_password', secret=True),
    cfg.StrOpt('alt_domain_name'),

    cfg.StrOpt('admin_username'),
    cfg.StrOpt('admin_tenant_name'),
    cfg.StrOpt('admin_password', secret=True),
    cfg.StrOpt('admin_domain_name'),

    cfg.StrOpt("override_endpoint",
               help="use this url instead of the url in the service catalog"),
    cfg.StrOpt("override_token",
               help="with the override endpoint, pass this token to the api"),
], group='identity')


cfg.CONF.register_opts([
    cfg.StrOpt('directory',
               help='the directory containing the client executable'),
], group='designateclient')


def find_config_file():
    return os.environ.get(
        'TEMPEST_CONFIG', '/opt/stack/tempest/etc/tempest.conf')


def read_config():
    cfg.CONF(args=[], default_config_files=[find_config_file()])



"""
Copyright 2015 Rackspace

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
"""
import logging
import os

from tempest.lib.cli import base

from designateclient.functionaltests.config import cfg
from designateclient.functionaltests.models import FieldValueModel
from designateclient.functionaltests.models import ListModel


LOG = logging.getLogger(__name__)


def build_option_string(options):
    """Format a string of option flags (--key 'value').

    This will quote the values, in case spaces are included.
    Any values that are None are excluded entirely.

    Usage::

        build_option_string({
            "--email": "me@example.com",
            "--name": "example.com."
            "--ttl": None,

        })

    Returns::

        "--email 'me@example.com' --name 'example.com.'
    """
    return " ".join("{0} '{1}'".format(flag, value)
                    for flag, value in options.items()
                    if value is not None)


def build_flags_string(flags):
    """Format a string of value-less flags.

    Pass in a dictionary mapping flags to booleans. Those flags set to true
    are included in the returned string.

    Usage::

        build_flags_string({
            '--no-ttl': True,
            '--no-name': False,
            '--verbose': True,
        })

    Returns::

        '--no-ttl --verbose'
    """
    flags = {flag: is_set for flag, is_set in flags.items() if is_set}
    return " ".join(flags.keys())


class ZoneCommands(object):
    """This is a mixin that provides zone commands to DesignateCLI"""

    def zone_list(self, *args, **kwargs):
        return self.parsed_cmd('zone list', ListModel, *args, **kwargs)

    def zone_show(self, id, *args, **kwargs):
        return self.parsed_cmd('zone show %s' % id, FieldValueModel, *args,
                               **kwargs)

    def zone_delete(self, id, *args, **kwargs):
        return self.parsed_cmd('zone delete %s' % id, FieldValueModel, *args,
                               **kwargs)

    def zone_create(self, name, email=None, ttl=None, description=None,
                    type=None, masters=None, *args, **kwargs):
        options_str = build_option_string({
            "--email": email,
            "--ttl": ttl,
            "--description": description,
            "--masters": masters,
            "--type": type,
        })
        cmd = 'zone create {0} {1}'.format(name, options_str)
        return self.parsed_cmd(cmd, FieldValueModel, *args, **kwargs)

    def zone_set(self, id, email=None, ttl=None, description=None,
                 type=None, masters=None, *args, **kwargs):
        options_str = build_option_string({
            "--email": email,
            "--ttl": ttl,
            "--description": description,
            "--masters": masters,
            "--type": type,
        })
        cmd = 'zone set {0} {1}'.format(id, options_str)
        return self.parsed_cmd(cmd, FieldValueModel, *args, **kwargs)


class ZoneTransferCommands(object):
    """A mixin for DesignateCLI to add zone transfer commands"""

    def zone_transfer_request_list(self, *args, **kwargs):
        cmd = 'zone transfer request list'
        return self.parsed_cmd(cmd, ListModel, *args, **kwargs)

    def zone_transfer_request_create(self, zone_id, target_project_id=None,
                                     description=None, *args, **kwargs):
        options_str = build_option_string({
            "--target-project-id": target_project_id,
            "--description": description,
        })
        cmd = 'zone transfer request create {0} {1}'.format(
            zone_id, options_str)
        return self.parsed_cmd(cmd, FieldValueModel, *args, **kwargs)

    def zone_transfer_request_show(self, id, *args, **kwargs):
        cmd = 'zone transfer request show {0}'.format(id)
        return self.parsed_cmd(cmd, FieldValueModel, *args, **kwargs)

    def zone_transfer_request_set(self, id, description=None, *args, **kwargs):
        options_str = build_option_string({"--description": description})
        cmd = 'zone transfer request set {0} {1}'.format(options_str, id)
        return self.parsed_cmd(cmd, FieldValueModel, *args, **kwargs)

    def zone_transfer_request_delete(self, id, *args, **kwargs):
        cmd = 'zone transfer request delete {0}'.format(id)
        return self.parsed_cmd(cmd, *args, **kwargs)

    def zone_transfer_accept_request(self, id, key, *args, **kwargs):
        options_str = build_option_string({
            "--transfer-id": id,
            "--key": key,
        })
        cmd = 'zone transfer accept request {0}'.format(options_str)
        return self.parsed_cmd(cmd, *args, **kwargs)

    def zone_transfer_accept_show(self, id, *args, **kwargs):
        cmd = 'zone transfer accept show {0}'.format(id)
        return self.parsed_cmd(cmd, FieldValueModel, *args, **kwargs)

    def zone_transfer_accept_list(self, *args, **kwargs):
        cmd = 'zone transfer accept list'
        return self.parsed_cmd(cmd, ListModel, *args, **kwargs)


class ZoneExportCommands(object):
    """A mixin for DesignateCLI to add zone export commands"""

    def zone_export_list(self, *args, **kwargs):
        cmd = 'zone export list'
        return self.parsed_cmd(cmd, ListModel, *args, **kwargs)

    def zone_export_create(self, zone_id, *args, **kwargs):
        cmd = 'zone export create {0}'.format(
            zone_id)
        return self.parsed_cmd(cmd, FieldValueModel, *args, **kwargs)

    def zone_export_show(self, zone_export_id, *args, **kwargs):
        cmd = 'zone export show {0}'.format(zone_export_id)
        return self.parsed_cmd(cmd, FieldValueModel, *args, **kwargs)

    def zone_export_delete(self, zone_export_id, *args, **kwargs):
        cmd = 'zone export delete {0}'.format(zone_export_id)
        return self.parsed_cmd(cmd, *args, **kwargs)

    def zone_export_showfile(self, zone_export_id, *args, **kwargs):
        cmd = 'zone export showfile {0}'.format(zone_export_id)
        return self.parsed_cmd(cmd, FieldValueModel, *args, **kwargs)


class ZoneImportCommands(object):
    """A mixin for DesignateCLI to add zone import commands"""

    def zone_import_list(self, *args, **kwargs):
        cmd = 'zone import list'
        return self.parsed_cmd(cmd, ListModel, *args, **kwargs)

    def zone_import_create(self, zone_file_path, *args, **kwargs):
        cmd = 'zone import create {0}'.format(zone_file_path)
        return self.parsed_cmd(cmd, FieldValueModel, *args, **kwargs)

    def zone_import_show(self, zone_import_id, *args, **kwargs):
        cmd = 'zone import show {0}'.format(zone_import_id)
        return self.parsed_cmd(cmd, FieldValueModel, *args, **kwargs)

    def zone_import_delete(self, zone_import_id, *args, **kwargs):
        cmd = 'zone import delete {0}'.format(zone_import_id)
        return self.parsed_cmd(cmd, *args, **kwargs)


class RecordsetCommands(object):

    def recordset_show(self, zone_id, id, *args, **kwargs):
        cmd = 'recordset show {0} {1}'.format(zone_id, id)
        return self.parsed_cmd(cmd, FieldValueModel, *args, **kwargs)

    def recordset_list(self, zone_id, *args, **kwargs):
        cmd = 'recordset list {0}'.format(zone_id)
        return self.parsed_cmd(cmd, ListModel, *args, **kwargs)

    def recordset_create(self, zone_id, name, records=None, type=None,
                         description=None, ttl=None, *args, **kwargs):
        options_str = build_option_string({
            '--records': records,
            '--type': type,
            '--description': description,
            '--ttl': ttl,
        })
        cmd = 'recordset create {0} {1} {2}'.format(zone_id, name, options_str)
        return self.parsed_cmd(cmd, FieldValueModel, *args, **kwargs)

    def recordset_set(self, zone_id, id, records=None, type=None,
                      description=None, ttl=None, no_description=False,
                      no_ttl=False, *args, **kwargs):
        options_str = build_option_string({
            '--records': records,
            '--type': type,
            '--description': description,
            '--ttl': ttl,
        })
        flags_str = build_flags_string({
            '--no-description': no_description,
            '--no-ttl': no_ttl,
        })
        cmd = 'recordset set {0} {1} {2} {3}'.format(
            zone_id, id, flags_str, options_str)
        return self.parsed_cmd(cmd, FieldValueModel, *args, **kwargs)

    def recordset_delete(self, zone_id, id, *args, **kwargs):
        cmd = 'recordset delete {0} {1}'.format(zone_id, id)
        return self.parsed_cmd(cmd, FieldValueModel, *args, **kwargs)


class TLDCommands(object):

    def tld_list(self, *args, **kwargs):
        return self.parsed_cmd('tld list', ListModel, *args, **kwargs)

    def tld_show(self, id, *args, **kwargs):
        return self.parsed_cmd('tld show {0}'.format(id), FieldValueModel,
                               *args, **kwargs)

    def tld_delete(self, id, *args, **kwargs):
        return self.parsed_cmd('tld delete {0}'.format(id), *args, **kwargs)

    def tld_create(self, name, description=None, *args, **kwargs):
        options_str = build_option_string({
            '--name': name,
            '--description': description,
        })
        cmd = 'tld create {0}'.format(options_str)
        return self.parsed_cmd(cmd, FieldValueModel, *args, **kwargs)

    def tld_set(self, id, name=None, description=None, no_description=False,
                *args, **kwargs):
        options_str = build_option_string({
            '--name': name,
            '--description': description,
        })
        flags_str = build_flags_string({'--no-description': no_description})
        cmd = 'tld set {0} {1} {2}'.format(id, options_str, flags_str)
        return self.parsed_cmd(cmd, FieldValueModel, *args, **kwargs)


class TSIGKeyCommands(object):
    def tsigkey_list(self, *args, **kwargs):
        return self.parsed_cmd('tsigkey list', ListModel, *args, **kwargs)

    def tsigkey_show(self, id, *args, **kwargs):
        return self.parsed_cmd('tsigkey show {0}'.format(id), FieldValueModel,
                               *args, **kwargs)

    def tsigkey_delete(self, id, *args, **kwargs):
        return self.parsed_cmd('tsigkey delete {0}'.format(id), *args,
                               **kwargs)

    def tsigkey_create(self, name, algorithm, secret, scope, resource_id,
                       *args, **kwargs):
        options_str = build_option_string({
            '--name': name,
            '--algorithm': algorithm,
            '--secret': secret,
            '--scope': scope,
            '--resource-id': resource_id,
        })
        cmd = 'tsigkey create {0}'.format(options_str)
        return self.parsed_cmd(cmd, FieldValueModel, *args, **kwargs)

    def tsigkey_set(self, id, name=None, algorithm=None, secret=None,
                    scope=None,
                    *args, **kwargs):
        options_str = build_option_string({
            '--name': name,
            '--algorithm': algorithm,
            '--secret': secret,
            '--scope': scope,
        })
        cmd = 'tsigkey set {0} {1}'.format(id, options_str)
        return self.parsed_cmd(cmd, FieldValueModel, *args, **kwargs)


class BlacklistCommands(object):
    def zone_blacklist_list(self, *args, **kwargs):
        cmd = 'zone blacklist list'
        return self.parsed_cmd(cmd, ListModel, *args, **kwargs)

    def zone_blacklist_create(self, pattern, description=None, *args,
                              **kwargs):
        options_str = build_option_string({
            '--pattern': pattern,
            '--description': description,
        })
        cmd = 'zone blacklist create {0}'.format(options_str)
        return self.parsed_cmd(cmd, FieldValueModel, *args, **kwargs)

    def zone_blacklist_set(self, id, pattern=None, description=None,
                           no_description=False, *args, **kwargs):
        options_str = build_option_string({
            '--pattern': pattern,
            '--description': description,
        })
        flags_str = build_flags_string({'--no-description': no_description})
        cmd = 'zone blacklist set {0} {1} {2}'.format(id, options_str,
                                                      flags_str)
        return self.parsed_cmd(cmd, FieldValueModel, *args, **kwargs)

    def zone_blacklist_show(self, id, *args, **kwargs):
        cmd = 'zone blacklist show {0}'.format(id)
        return self.parsed_cmd(cmd, FieldValueModel, *args, **kwargs)

    def zone_blacklist_delete(self, id, *args, **kwargs):
        cmd = 'zone blacklist delete {0}'.format(id)
        return self.parsed_cmd(cmd, FieldValueModel, *args, **kwargs)


class DesignateCLI(base.CLIClient, ZoneCommands, ZoneTransferCommands,
                   ZoneExportCommands, ZoneImportCommands, RecordsetCommands,
                   TLDCommands, BlacklistCommands):

    # instantiate this once to minimize requests to keystone
    _CLIENTS = None

    def __init__(self, *args, **kwargs):
        super(DesignateCLI, self).__init__(*args, **kwargs)
        # grab the project id. this is used for zone transfer requests
        resp = FieldValueModel(self.openstack('token issue'))
        self.project_id = resp.project_id

    @property
    def using_auth_override(self):
        return bool(cfg.CONF.identity.override_endpoint)

    @classmethod
    def get_clients(cls):
        if not cls._CLIENTS:
            cls._init_clients()
        return cls._CLIENTS

    @classmethod
    def _init_clients(cls):
        cls._CLIENTS = {
            'default': DesignateCLI(
                cli_dir=cfg.CONF.designateclient.directory,
                username=cfg.CONF.identity.username,
                password=cfg.CONF.identity.password,
                tenant_name=cfg.CONF.identity.tenant_name,
                uri=cfg.CONF.identity.uri,
            ),
            'alt': DesignateCLI(
                cli_dir=cfg.CONF.designateclient.directory,
                username=cfg.CONF.identity.alt_username,
                password=cfg.CONF.identity.alt_password,
                tenant_name=cfg.CONF.identity.alt_tenant_name,
                uri=cfg.CONF.identity.uri,
            ),
            'admin': DesignateCLI(
                cli_dir=cfg.CONF.designateclient.directory,
                username=cfg.CONF.identity.admin_username,
                password=cfg.CONF.identity.admin_password,
                tenant_name=cfg.CONF.identity.admin_tenant_name,
                uri=cfg.CONF.identity.uri,
            )
        }

    @classmethod
    def as_user(self, user):
        clients = self.get_clients()
        if user in clients:
            return clients[user]
        raise Exception("User '{0}' does not exist".format(user))

    def parsed_cmd(self, cmd, model=None, *args, **kwargs):
        if self.using_auth_override:
            # use --os-url and --os-token
            func = self._openstack_noauth
        else:
            # use --os-username --os-tenant-name --os-password --os-auth-url
            func = self.openstack

        out = func(cmd, *args, **kwargs)
        LOG.debug(out)
        if model is not None:
            return model(out)
        return out

    def _openstack_noauth(self, cmd, *args, **kwargs):
        exe = os.path.join(cfg.CONF.designateclient.directory, 'openstack')
        options = build_option_string({
            '--os-url': cfg.CONF.identity.override_endpoint,
            '--os-token': cfg.CONF.identity.override_token,
        })
        cmd = options + " " + cmd
        return base.execute(exe, cmd, *args, **kwargs)



# Licensed under the Apache License, Version 2.0 (the "License"); you may
# not use this file except in compliance with the License. You may obtain
# a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
# License for the specific language governing permissions and limitations
# under the License.

from unittest import mock

from osc_lib.tests import utils

from designateclient.tests.osc import resources
from designateclient.v2 import base
from designateclient.v2.cli import recordsets


class TestDesignateCreateRecordSets(utils.TestCommand):
    def setUp(self):
        super(TestDesignateCreateRecordSets, self).setUp()
        self.app.client_manager.dns = mock.MagicMock()
        self.cmd = recordsets.CreateRecordSetCommand(self.app, None)
        self.dns_client = self.app.client_manager.dns

    def test_create_recordset(self):
        arg_list = [
            '6f106adb-0896-4114-b34f-4ac8dfee9465',
            'example',
            '--type', 'A',
            '--record', '127.0.0.1',
            '--record', '127.0.0.2',
        ]
        verify_args = [
            ('zone_id', '6f106adb-0896-4114-b34f-4ac8dfee9465'),
            ('name', 'example'),
            ('type', 'A'),
            ('record', ['127.0.0.1', '127.0.0.2']),
        ]

        body = resources.load('recordset_create')
        self.dns_client.recordsets.create.return_value = body

        parsed_args = self.check_parser(self.cmd, arg_list, verify_args)
        columns, data = self.cmd.take_action(parsed_args)

        results = list(data)

        self.assertEqual(14, len(results))


class TestDesignateListRecordSets(utils.TestCommand):
    def setUp(self):
        super(TestDesignateListRecordSets, self).setUp()
        self.app.client_manager.dns = mock.MagicMock()
        self.cmd = recordsets.ListRecordSetsCommand(self.app, None)
        self.dns_client = self.app.client_manager.dns

    def test_list_recordsets(self):
        arg_list = ['6f106adb-0896-4114-b34f-4ac8dfee9465']
        verify_args = [
            ('zone_id', '6f106adb-0896-4114-b34f-4ac8dfee9465'),
        ]

        body = resources.load('recordset_list')
        result = base.DesignateList()
        result.extend(body['recordsets'])

        self.dns_client.recordsets.list.return_value = result

        parsed_args = self.check_parser(self.cmd, arg_list, verify_args)
        columns, data = self.cmd.take_action(parsed_args)

        results = list(data)

        self.assertEqual(3, len(results))

    def test_list_all_recordsets(self):
        arg_list = ['all']
        verify_args = [
            ('zone_id', 'all'),
        ]

        body = resources.load('recordset_list_all')
        result = base.DesignateList()
        result.extend(body['recordsets'])

        self.dns_client.recordsets.list_all_zones.return_value = result

        parsed_args = self.check_parser(self.cmd, arg_list, verify_args)
        columns, data = self.cmd.take_action(parsed_args)

        results = list(data)

        self.assertEqual(5, len(results))



"""
Copyright 2015 Rackspace

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
"""
from tempest.lib.cli import base
from tempest.lib.exceptions import CommandFailed

from designateclient.functionaltests import client
from designateclient.functionaltests import config


class BaseDesignateTest(base.ClientTestBase):

    def _get_clients(self):
        config.read_config()
        return client.DesignateCLI.as_user('default')

    def ensure_tld_exists(self, tld):
        try:
            self.clients.as_user('admin').tld_create(tld)
        except CommandFailed:
            pass

    def _is_entity_in_list(self, entity, entity_list):
        """Determines if the given entity exists in the given list.

        Uses the id for comparison.

        Certain entities (e.g. zone import, export) cannot be made
        comparable in a list of CLI output results, because the fields
        in a list command can be different from those in a show command.

        """
        return any([entity_record.id == entity.id
                    for entity_record in entity_list])



# -*- coding: utf-8 -*-
#
# designateclient documentation build configuration file

# -- General configuration -----------------------------------------------------

# Add any Sphinx extension module names here, as strings. They can be extensions
# coming with Sphinx (named 'sphinx.ext.*') or your custom ones.
extensions = [
    'sphinx.ext.autodoc',
    'sphinx.ext.viewcode',
    'sphinxcontrib.apidoc',
    'openstackdocstheme',
    'cliff.sphinxext']

# openstackdocstheme options
openstackdocs_repo_name = 'openstack/python-designateclient'
openstackdocs_bug_project = 'python-designateclient'
openstackdocs_bug_tag = ''
html_theme = 'openstackdocs'

apidoc_module_dir = '../../designateclient'
apidoc_output_dir = 'reference/api'
apidoc_excluded_paths = [ 'tests/*', 'functionaltests/*', 'hacking/*' ]
apidoc_separate_modules = True

autodoc_exclude_modules = [
  'designateclient.tests.*',
  'designateclient.functionaltests.*',
  'designateclient.hacking.*']

# Add any paths that contain templates here, relative to this directory.
templates_path = ['_templates']

# The suffix of source filenames.
source_suffix = '.rst'

# The master toctree document.
master_doc = 'index'

# General information about the project.
copyright = u'2012, Managed I.T. 2013-2014, Hewlett-Packard Development Company, L.P.'

# List of patterns, relative to source directory, that match files and
# directories to ignore when looking for source files.
exclude_patterns = []

# The name of the Pygments (syntax highlighting) style to use.
pygments_style = 'native'

# A list of ignored prefixes for module index sorting.
modindex_common_prefix = ['designateclient']


# -- Options for HTML output ---------------------------------------------------

# Output file base name for HTML help builder.
htmlhelp_basename = 'designateclientdoc'



# Licensed under the Apache License, Version 2.0 (the "License"); you may
# not use this file except in compliance with the License. You may obtain
# a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
# License for the specific language governing permissions and limitations
# under the License.

from unittest import mock

from osc_lib.tests import utils

from designateclient.tests.osc import resources
from designateclient.v2 import base
from designateclient.v2.cli import zones


class TestDesignateCreateZone(utils.TestCommand):
    def setUp(self):
        super(TestDesignateCreateZone, self).setUp()
        self.app.client_manager.dns = mock.MagicMock()
        self.cmd = zones.CreateZoneCommand(self.app, None)
        self.dns_client = self.app.client_manager.dns

    def test_create_zone(self):
        arg_list = [
            'example.devstack.org.',
            '--email', 'fake@devstack.org',
        ]
        verify_args = [
            ('name', 'example.devstack.org.'),
            ('email', 'fake@devstack.org'),
        ]

        body = resources.load('zone_create')
        self.dns_client.zones.create.return_value = body

        parsed_args = self.check_parser(self.cmd, arg_list, verify_args)
        columns, data = self.cmd.take_action(parsed_args)

        results = list(data)

        self.assertEqual(17, len(results))


class TestDesignateListZones(utils.TestCommand):
    def setUp(self):
        super(TestDesignateListZones, self).setUp()
        self.app.client_manager.dns = mock.MagicMock()
        self.cmd = zones.ListZonesCommand(self.app, None)
        self.dns_client = self.app.client_manager.dns

    def test_list_zones(self):
        arg_list = []
        verify_args = []

        body = resources.load('zone_list')
        result = base.DesignateList()
        result.extend(body['zones'])

        self.dns_client.zones.list.return_value = result

        parsed_args = self.check_parser(self.cmd, arg_list, verify_args)
        columns, data = self.cmd.take_action(parsed_args)

        results = list(data)

        self.assertEqual(2, len(results))



import logging
import os

from designateclient.v2 import client
from designateclient import exceptions

from keystoneauth1.identity import generic
from keystoneauth1 import session as keystone_session


logging.basicConfig(level='DEBUG')

"""
Example script to create or get a domain and add some records to it.
"""


auth = generic.Password(
    auth_url=os.environ.get('OS_AUTH_URL'),
    username=os.environ.get('OS_USERNAME'),
    password=os.environ.get('OS_PASSWORD'),
    project_name=os.environ.get('OS_PROJECT_NAME'),
    project_domain_id='default',
    user_domain_id='default')

session = keystone_session.Session(auth=auth)

client = client.Client(session=session)


try:
    zone = client.zones.create('i.io.', email='i@i.io')
except exceptions.RemoteError:
    zone = dict([(z['name'], z) for z in client.zones.list()])['i.io.']

print("Recordset list...")
for rs in client.recordsets.list(zone['id']):
    print(rs)

# Here's an example of just passing "www" as the record name vs "www.i.io."
records = ["10.0.0.1"]
rs = client.recordsets.create(zone['id'], 'www', 'A', records)

# Here we're replacing the records with new ones
records = ["10.0.0.1", "10.0.0.5"]
client.recordsets.update(zone['id'], rs['id'], {'records': records})
